==> haskell-skylighting-format-blaze-html-0.1.1.3-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-A1JMrlojV061FV0GayGovp

key:
    skylighting-format-blaze-html-0.1.1.3-A1JMrlojV061FV0GayGovp

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  e81ac2a080fdfadad82bfbabe38a6dd5
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-A1JMrlojV061FV0GayGovp

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-D6khwrbejGRHAmMP2tGf4Z
    containers-0.6.7 skylighting-core-0.14.2-HWUDMP1nyovD4uLcT7gefS
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-blaze-html-0.1.1.3-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-E8F2n2YdhnuAzWuoeac3Mm

key:
    skylighting-format-blaze-html-0.1.1.3-E8F2n2YdhnuAzWuoeac3Mm

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  997704f6d0f5acdfc946cef85a2e3f27
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-E8F2n2YdhnuAzWuoeac3Mm

depends:
    base-4.17.2.1 blaze-html-0.9.2.0-Cv5u1eWpWkgLQ3EG0vDZlF
    containers-0.6.7 skylighting-core-0.14.2-TPZgAjtukZF7agqJczPYH
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
